<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="auth_dialog.ui" line="32"/>
        <source>Get Auth code</source>
        <translation>認証コードを取得</translation>
    </message>
    <message>
        <location filename="auth_dialog.ui" line="78"/>
        <source>1. Click the following button to open permission page</source>
        <translation>1. このボタンをクリックすると認証ページが開きます。</translation>
    </message>
    <message>
        <location filename="auth_dialog.ui" line="91"/>
        <source>2. Allow the access in the page, and copy&amp;paste the auth code in the box below</source>
        <translation>2. 認証すると表示される認証コードを下にあるテキストボックスに貼り付けてください。</translation>
    </message>
    <message>
        <location filename="auth_dialog.ui" line="123"/>
        <source>Open Browser...</source>
        <translation>ブラウザを開く...</translation>
    </message>
</context>
<context>
    <name>CharacterFormEditor</name>
    <message>
        <source>Fullwidth</source>
        <translation type="obsolete">全角</translation>
    </message>
    <message>
        <source>Halfwidth</source>
        <translation type="obsolete">半角</translation>
    </message>
    <message>
        <source>Remember</source>
        <translation type="obsolete">学習</translation>
    </message>
    <message>
        <source>Character form editor</source>
        <translation type="obsolete">半角・全角設定</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="obsolete">文字グループ</translation>
    </message>
    <message>
        <source>Composition</source>
        <translation type="obsolete">変換前文字列</translation>
    </message>
    <message>
        <source>Conversion</source>
        <translation type="obsolete">変換中文字列</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Custom keymap</source>
        <translation type="obsolete">カスタム</translation>
    </message>
    <message>
        <source>Kotoeri</source>
        <translation type="obsolete">ことえり</translation>
    </message>
    <message>
        <source>Romaji</source>
        <translation type="obsolete">ローマ字入力</translation>
    </message>
    <message>
        <source>Kana</source>
        <translation type="obsolete">かな入力</translation>
    </message>
    <message>
        <source>Romaji (switchable)</source>
        <translation type="obsolete">ローマ字入力 (切替可)</translation>
    </message>
    <message>
        <source>Kana (switchable)</source>
        <translation type="obsolete">かな入力 (切替可)</translation>
    </message>
    <message>
        <source>Follow input mode</source>
        <translation type="obsolete">入力モードに従う</translation>
    </message>
    <message>
        <source>Fullwidth</source>
        <translation type="obsolete">全角</translation>
    </message>
    <message>
        <source>Halfwidth</source>
        <translation type="obsolete">半角</translation>
    </message>
    <message>
        <source>No shortcut</source>
        <translation type="obsolete">なし</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">有効</translation>
    </message>
    <message>
        <source>Yes (don&apos;t record new data)</source>
        <translation type="obsolete">有効（新規学習はしない）</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">無効</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="obsolete">オフ</translation>
    </message>
    <message>
        <source>Alphanumeric</source>
        <translation type="obsolete">英数字</translation>
    </message>
    <message>
        <source>Katakana</source>
        <translation type="obsolete">カタカナ</translation>
    </message>
    <message>
        <source>Direct input</source>
        <translation type="obsolete">直接入力</translation>
    </message>
    <message>
        <source>Yen Sign Â¥</source>
        <translation type="obsolete">円記号(¥)</translation>
    </message>
    <message>
        <source>Backslash \</source>
        <translation type="obsolete">バックスラッシュ(\)</translation>
    </message>
    <message>
        <source>Dictionary preloading</source>
        <translation type="obsolete">オンメモリ辞書の設定</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="32"/>
        <source>Mozc settings</source>
        <translation>Mozc プロパティ</translation>
    </message>
    <message>
        <source>Failed to get current config values</source>
        <translation type="obsolete">設定の取得に失敗しました。</translation>
    </message>
    <message>
        <source>The current custom keymap table is empty. When custom keymap is selected, you must customize it.</source>
        <translation type="obsolete">有効なキー設定がありません。カスタム キーマップを選択した場合は、キーマップを編集する必要があります。</translation>
    </message>
    <message>
        <source>Romaji/Kana setting is enabled from new applications.</source>
        <translation type="obsolete">ローマ字・かな入力の設定は新しいアプリケーションから有効になります。</translation>
    </message>
    <message>
        <source>Failed to update config</source>
        <translation type="obsolete">設定の反映に失敗しました</translation>
    </message>
    <message>
        <source>Checking sync status</source>
        <translation type="obsolete">同期状態を確認する</translation>
    </message>
    <message>
        <source>Sync is not enabled</source>
        <translation type="obsolete">同期機能：オフ</translation>
    </message>
    <message>
        <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
        <translation type="obsolete">学習結果がリセットされます。実行しますか？ 入力履歴データはリセットされません。入力履歴データのリセットは「サジェスト→全入力履歴の削除」で行えます。</translation>
    </message>
    <message>
        <source>Mozc Converter is not running. Settings were not saved.</source>
        <translation type="obsolete">変換サーバが反応していません。設定の反映に失敗しました。</translation>
    </message>
    <message>
        <source>Do you want to clear all history data?</source>
        <translation type="obsolete">すべての入力履歴が削除されます。実行しますか？</translation>
    </message>
    <message>
        <source>Mozc Converter is not running. Settings were not saved</source>
        <translation type="obsolete">変換サーバが反応していません。設定の反映に失敗しました。</translation>
    </message>
    <message>
        <source>Do you want to clear unused history data?</source>
        <translation type="obsolete">サジェスト経由で入力されなかった履歴が削除されます。実行しますか？</translation>
    </message>
    <message>
        <source>Mozc Converter is not running. operation was not executed</source>
        <translation type="obsolete">Mozcコンバーターが起動していません。設定の反映に失敗しました。</translation>
    </message>
    <message>
        <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
 - Personalization data
 - Input history
 - Sync settings
 - Usage statistics and crash reports
 - Administrator settings</source>
        <translation type="obsolete">この機能を実行すると Mozcの設定が標準状態に戻ります。実行しますか？ 以下の設定はリセットされません。
 - 学習履歴
 - 入力履歴
 - 同期設定
 - 使用統計と障害レポート
 - 管理者用設定</translation>
    </message>
    <message>
        <source>Stop Sync</source>
        <translation type="obsolete">同期の解除</translation>
    </message>
    <message>
        <source>Last synced time: </source>
        <translation type="obsolete">最終同期時刻: </translation>
    </message>
    <message>
        <source>Sync succeeded. </source>
        <translation type="obsolete">同期成功</translation>
    </message>
    <message>
        <source>Sync failed</source>
        <translation type="obsolete">同期失敗</translation>
    </message>
    <message>
        <source>During synchronization</source>
        <translation type="obsolete">同期中です</translation>
    </message>
    <message>
        <source>Clear all sync data in Google servers</source>
        <translation type="obsolete">Google サーバー上の同期データを全て消去する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1350"/>
        <source>Clear all sync data in Google servers. To delete data completely, make sure there is no other machine which is running sync and stop sync on this machine after clearing the data.</source>
        <translation>同期サーバーにあるデータを全て消去します。データを消去したままにするには、他のコンピュータで実行している同期をあらかじめ解除し、消去の実行後にこのコンピュータの同期も解除してください。</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="57"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="92"/>
        <source>Input mode</source>
        <translation>ローマ字入力・かな入力</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="99"/>
        <source>Punctuation style</source>
        <translation>句読点</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="106"/>
        <source>Symbol style</source>
        <translation>記号</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="113"/>
        <source>Space input style</source>
        <translation>スペースの入力</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="123"/>
        <source>Selection shortcut</source>
        <translation>候補選択ショートカット</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="130"/>
        <source>Numpad style</source>
        <translation>テンキーからの入力</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="172"/>
        <source>Keymap style</source>
        <translation>キー設定の選択</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="185"/>
        <location filename="config_dialog.ui" line="192"/>
        <location filename="config_dialog.ui" line="632"/>
        <location filename="config_dialog.ui" line="1308"/>
        <source>Customize...</source>
        <translation>編集...</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="218"/>
        <source>Basics</source>
        <translation>基本設定</translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="147"/>
        <source>character entered by ¥ key</source>
        <translation>¥キーで入力する文字</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1027"/>
        <source>Privacy</source>
        <translation>プライバシー</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="250"/>
        <source>Keymap</source>
        <translation>キー設定</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1242"/>
        <source>Cloud</source>
        <translation>クラウド</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1257"/>
        <source>Sync</source>
        <translation>同期</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1295"/>
        <source>Start Sync</source>
        <translation>同期する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="272"/>
        <source>Dictionary</source>
        <translation>辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="287"/>
        <source>Clear personalization data</source>
        <translation>学習履歴のクリア</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="294"/>
        <source>Adjust conversion based on previous input</source>
        <translation>学習機能</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="383"/>
        <source>Single kanji dictionary</source>
        <translation>単漢字辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="390"/>
        <source>Symbol dictionary</source>
        <translation>記号辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="397"/>
        <source>Date/time conversion</source>
        <translation>日付変換を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="404"/>
        <source>Special number conversion</source>
        <translation>数字変換を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="411"/>
        <source>Emoticon dictionary</source>
        <translation>顔文字辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="418"/>
        <source>Calculator</source>
        <translation>計算機機能を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="425"/>
        <source>Spelling correction</source>
        <translation>「もしかして」機能を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="432"/>
        <source>Katakana to English dictionary</source>
        <translation>カタカナ英語辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="439"/>
        <source>Zip code dictionary</source>
        <translation>郵便番号辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="490"/>
        <source>Additional dictionaries</source>
        <translation>その他の辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="554"/>
        <source>Special conversions</source>
        <translation>特殊変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="586"/>
        <source>Usage dictionary</source>
        <translation>用例辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="618"/>
        <source>homonym dictionary</source>
        <translation>同音異義語辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="625"/>
        <source>Web extention</source>
        <translation>Web 拡張</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="654"/>
        <source>Advanced</source>
        <translation>入力補助</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="743"/>
        <source>Automatically switch to halfwidth</source>
        <translation>自動英数変換を有効にする</translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="773"/>
        <source>、</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="786"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="793"/>
        <source>Convert at punctuations</source>
        <translation>句読点変換を有効にする</translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="806"/>
        <source>。</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="819"/>
        <source>!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="829"/>
        <source>Always use Ja keyboard layout for Japanese input</source>
        <translation>日本語入力では常に日本語キー配列を使う</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="853"/>
        <source>Source data</source>
        <translation>サジェストの種類</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="885"/>
        <source>Other settings</source>
        <translation>その他の設定</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="952"/>
        <source>Use input history</source>
        <translation>入力履歴からのサジェスト自動表示を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="972"/>
        <source>Use system dictionary</source>
        <translation>システム辞書からのサジェスト自動表示を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="364"/>
        <source>Edit user dictionary...</source>
        <translation>ユーザ辞書の編集...</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="199"/>
        <source>Romaji table</source>
        <translation>ローマ字テーブル</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="458"/>
        <source>Personalization</source>
        <translation>学習</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="522"/>
        <source>User dictionary</source>
        <translation>ユーザー辞書</translation>
    </message>
    <message>
        <source>Halfiwidth/Fullwidth</source>
        <translation type="obsolete">半角・全角</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="679"/>
        <source>Input Assistance</source>
        <translation>入力補助</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="711"/>
        <source>Fullwidth/Halfwidth</source>
        <translation>半角・全角</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="750"/>
        <source>Shift key mode switch</source>
        <translation>シフトキーでの入力切替</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="838"/>
        <source>Suggest</source>
        <translation>サジェスト</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="917"/>
        <source>Maximum number of suggestions</source>
        <translation>サジェストの最大候補数</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="965"/>
        <source>Clear all history</source>
        <translation>全入力履歴を削除</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="985"/>
        <source>Clear unused history</source>
        <translation>未使用の履歴を削除</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1018"/>
        <source>Use realtime conversion</source>
        <translation>リアルタイム変換を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1112"/>
        <source>Secret mode</source>
        <translation>シークレットモード</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1163"/>
        <source>Temporarily disable conversion personalization, history-based suggestions and user dictionary</source>
        <translation>一時的に学習機能、入力履歴からのサジェスト機能、ユーザ辞書機能を無効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1204"/>
        <source>Temporarily disable all suggestions</source>
        <translation>一時的にすべてのサジェスト機能を無効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1220"/>
        <source>Presentation mode</source>
        <translation>プレゼンテーションモード</translation>
    </message>
    <message>
        <source>Clear Sync</source>
        <translation type="obsolete">同期を解除</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1337"/>
        <source>latest sync</source>
        <translation>最終同期時刻</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1411"/>
        <source>Other Cloud based feature</source>
        <translation>その他のクラウド機能</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1433"/>
        <source>Misc</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1480"/>
        <source>Logging level (debug only)</source>
        <translation>ログレベル（デバッグ）</translation>
    </message>
    <message>
        <source>Enable protocol logging (debug only)</source>
        <translation type="obsolete">プロトコル ログを有効にする（デバッグ）</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1509"/>
        <source>Logging</source>
        <translation>ログ</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1541"/>
        <source>Administration</source>
        <translation>管理</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1191"/>
        <location filename="config_dialog.ui" line="1579"/>
        <source>Settings...</source>
        <translation>設定変更...</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1599"/>
        <source>Dictionary preloading and UAC settings</source>
        <translation>オンメモリ辞書とUACの設定</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1080"/>
        <source>Usage statistics and crash reports</source>
        <translation>使用統計情報と障害レポート</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1061"/>
        <source>Help make Mozc better by automatically sending usage statistics and crash reports to Google (changes will take effect after you log out and log back in)</source>
        <translation>使用統計データや障害レポートを Google に自動送信して
Mozcの機能向上に役立てる（再ログイン後に変更は完了します）</translation>
    </message>
    <message>
        <source>Remove the uploaded data</source>
        <translation type="obsolete">アップロードされたデータを削除する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1366"/>
        <source>Remove all</source>
        <translation>全て削除</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1379"/>
        <source>Mozc can securely syncs your settings and a user sync-dictionary among different machines</source>
        <translation>設定や同期用ユーザー辞書を、異なるコンピュータ間で安全に同期します</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1395"/>
        <source>Enable Cloud handwriting recognition</source>
        <translation>クラウド手書き文字認識を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1624"/>
        <source>Check if Mozc is the default IME on startup</source>
        <translation>起動時に Mozcが既定の IME であるか確認する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1634"/>
        <source>Disable Keyboard layout hotkey (Ctrl+Shift)</source>
        <translation>ホットキー(Ctrl+Shift)による IME の切り替えを無効化する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1448"/>
        <source>Default IME</source>
        <translation>既定の IME</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1673"/>
        <source>Reset to defaults</source>
        <translation>初期値に戻す</translation>
    </message>
</context>
<context>
    <name>GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.ui" line="14"/>
        <source>Mozc</source>
        <translation>Mozc</translation>
    </message>
    <message>
        <location filename="generic_table_editor.ui" line="62"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Mozc settings</source>
        <translation type="obsolete">Mozcプロパティ</translation>
    </message>
    <message>
        <source>No entry is selected</source>
        <translation type="obsolete">エントリーが選択されていません</translation>
    </message>
    <message>
        <source>You can&apos;t have more than %1 entries</source>
        <translation type="obsolete">%1 個以上のエントリーは登録できません</translation>
    </message>
    <message>
        <source>import from file</source>
        <translation type="obsolete">インポート</translation>
    </message>
    <message>
        <source>File not found</source>
        <translation type="obsolete">ファイルが見つかりません</translation>
    </message>
    <message>
        <source>The specified file is too large (&gt;=100K byte)</source>
        <translation type="obsolete">ファイルサイズが大きすぎて読み込めません</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation type="obsolete">インポートに失敗しました</translation>
    </message>
    <message>
        <source>export to file</source>
        <translation type="obsolete">エクスポート</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="obsolete">エクスポートに失敗しました</translation>
    </message>
    <message>
        <source>New entry</source>
        <translation type="obsolete">新しいエントリー</translation>
    </message>
    <message>
        <source>Remove entry</source>
        <translation type="obsolete">エントリーを削除</translation>
    </message>
</context>
<context>
    <name>KeyBindingEditor</name>
    <message>
        <location filename="keybinding_editor.ui" line="32"/>
        <source>Mozc key binding editor</source>
        <translation>Mozc キーバインディング 設定</translation>
    </message>
    <message>
        <location filename="keybinding_editor.ui" line="92"/>
        <source>Input key assignments:</source>
        <translation>割り当てるキーの入力:</translation>
    </message>
</context>
<context>
    <name>KeyMapEditorDialog</name>
    <message>
        <source>New entry</source>
        <translation type="obsolete">新しいエントリー</translation>
    </message>
    <message>
        <source>Remove selected entries</source>
        <translation type="obsolete">選択されたエントリーを削除</translation>
    </message>
    <message>
        <source>Import predefined mapping</source>
        <translation type="obsolete">定義済みのキーマップからインポート</translation>
    </message>
    <message>
        <source>Kotoeri</source>
        <translation type="obsolete">ことえり</translation>
    </message>
    <message>
        <source>Import from file...</source>
        <translation type="obsolete">インポート...</translation>
    </message>
    <message>
        <source>Export to file...</source>
        <translation type="obsolete">エクスポート...</translation>
    </message>
    <message>
        <source>Mozc keymap editor</source>
        <translation type="obsolete">Mozc キー設定</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation type="obsolete">モード</translation>
    </message>
    <message>
        <source>Key</source>
        <translation type="obsolete">入力キー</translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="obsolete">コマンド</translation>
    </message>
    <message>
        <source>Mozc settings</source>
        <translation type="obsolete">Mozcプロパティ</translation>
    </message>
    <message>
        <source>Current keymap table is empty. You might want to import a pre-defined keymap table first</source>
        <translation type="obsolete">有効なキーマップがありません。定義済みのキーマップをインポートするか、有効なキーマップを追加してください。</translation>
    </message>
    <message>
        <source>Invalid key:
%1</source>
        <translation type="obsolete">無効な入力キーです:
%1</translation>
    </message>
    <message>
        <source>The keymaps for IME ON and Reconversion will be applied after new applications.</source>
        <translation type="obsolete">IME の有効化と再変換に対するキー設定は、新しいアプリケーションから有効になります。</translation>
    </message>
    <message>
        <source>Do you want to overwrite the current keymaps?</source>
        <translation type="obsolete">現在のキー設定が上書きされます。実行しますか？</translation>
    </message>
    <message>
        <source>Import/Export</source>
        <translation type="obsolete">インポート・エクスポート</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="character_form_editor.cc" line="16"/>
        <location filename="character_form_editor.cc" line="31"/>
        <source>Fullwidth</source>
        <translation>全角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="19"/>
        <location filename="character_form_editor.cc" line="33"/>
        <source>Halfwidth</source>
        <translation>半角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="22"/>
        <location filename="character_form_editor.cc" line="35"/>
        <source>Remember</source>
        <translation>学習</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="25"/>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="44"/>
        <location filename="character_form_editor.cc" line="54"/>
        <location filename="character_form_editor.cc" line="124"/>
        <source>Katakana</source>
        <translation>カタカナ</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="46"/>
        <location filename="character_form_editor.cc" line="57"/>
        <source>Numbers</source>
        <translation>数字</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="48"/>
        <location filename="character_form_editor.cc" line="59"/>
        <source>Alphabets</source>
        <translation>アルファベット</translation>
    </message>
</context>
<context>
    <name>RomanTableEditorDialog</name>
    <message>
        <source>New entry</source>
        <translation type="obsolete">新しいエントリー</translation>
    </message>
    <message>
        <source>Remove selected entries</source>
        <translation type="obsolete">選択されたエントリーを削除</translation>
    </message>
    <message>
        <source>Import from file...</source>
        <translation type="obsolete">インポート...</translation>
    </message>
    <message>
        <source>Export to file...</source>
        <translation type="obsolete">エクスポート...</translation>
    </message>
    <message>
        <source>Reset to defaults</source>
        <translation type="obsolete">初期値に戻す</translation>
    </message>
    <message>
        <source>Mozc Romaji table editor</source>
        <translation type="obsolete">Mozcローマ字テーブル設定</translation>
    </message>
    <message>
        <source>Input</source>
        <translation type="obsolete">入力</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="obsolete">出力</translation>
    </message>
    <message>
        <source>Next input</source>
        <translation type="obsolete">次の入力</translation>
    </message>
    <message>
        <source>Mozc settings</source>
        <translation type="obsolete">Mozcプロパティ</translation>
    </message>
    <message>
        <source>You can&apos;t have more than %1 entries</source>
        <translation type="obsolete">%1 個以上のエントリーは登録できません</translation>
    </message>
    <message>
        <source>Romaji to Kana table is empty.</source>
        <translation type="obsolete">ローマ字テーブルが空です</translation>
    </message>
    <message>
        <source>Input fields contain capital characters. &quot;Shift-mode-switch&quot; function is disabled with this new mapping.</source>
        <translation type="obsolete">入力フィールドに大文字のアルファベットが含まれています。新しい設定では「シフトキーによる入力切替」は無効になります。</translation>
    </message>
    <message>
        <source>Do you want to overwrite the current roman table?</source>
        <translation type="obsolete">現在のローマ字テーブルを上書きしますか？</translation>
    </message>
</context>
<context>
    <name>SyncCustomizeDialog</name>
    <message>
        <location filename="sync_customize_dialog.ui" line="26"/>
        <source>Dialog</source>
        <translation>同期の詳細設定</translation>
    </message>
    <message>
        <location filename="sync_customize_dialog.ui" line="54"/>
        <source>Sync everything</source>
        <translation>全て同期する</translation>
    </message>
    <message>
        <location filename="sync_customize_dialog.ui" line="70"/>
        <source>config</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="sync_customize_dialog.ui" line="77"/>
        <source>user dictionary</source>
        <translation>ユーザー辞書</translation>
    </message>
    <message>
        <source>learning data</source>
        <translation type="obsolete">学習履歴</translation>
    </message>
    <message>
        <source>input history</source>
        <translation type="obsolete">確定履歴</translation>
    </message>
    <message>
        <source>contact list</source>
        <translation type="obsolete">連絡先</translation>
    </message>
</context>
<context>
    <name>mozc::gui::CharacterFormEditor</name>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Fullwidth</source>
        <translation>全角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Halfwidth</source>
        <translation>半角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Remember</source>
        <translation>学習</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="73"/>
        <source>Character form editor</source>
        <translation>半角・全角設定</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Group</source>
        <translation>文字グループ</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Composition</source>
        <translation>変換前文字列</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Conversion</source>
        <translation>変換中文字列</translation>
    </message>
</context>
<context>
    <name>mozc::gui::ConfigDialog</name>
    <message>
        <location filename="config_dialog.cc" line="114"/>
        <location filename="config_dialog.cc" line="118"/>
        <source>Kotoeri</source>
        <translation>ことえり</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="111"/>
        <source>Custom keymap</source>
        <translation>カスタム</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="112"/>
        <location filename="config_dialog.cc" line="116"/>
        <source>ATOK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="113"/>
        <location filename="config_dialog.cc" line="117"/>
        <source>MS-IME</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="120"/>
        <source>Romaji</source>
        <translation>ローマ字入力</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="121"/>
        <source>Kana</source>
        <translation>かな入力</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="125"/>
        <source>Romaji (switchable)</source>
        <translation>ローマ字入力 (切替可)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="126"/>
        <source>Kana (switchable)</source>
        <translation>かな入力 (切替可)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="129"/>
        <location filename="config_dialog.cc" line="145"/>
        <source>Follow input mode</source>
        <translation>入力モードに従う</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="130"/>
        <location filename="config_dialog.cc" line="146"/>
        <source>Fullwidth</source>
        <translation>全角</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="131"/>
        <location filename="config_dialog.cc" line="147"/>
        <source>Halfwidth</source>
        <translation>半角</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="133"/>
        <source>No shortcut</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="134"/>
        <source>1 -- 9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="135"/>
        <source>A -- L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="137"/>
        <source>Yes</source>
        <translation>有効</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="138"/>
        <source>Yes (don&apos;t record new data)</source>
        <translation>有効（新規学習はしない）</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="139"/>
        <source>No</source>
        <translation>無効</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="141"/>
        <source>Off</source>
        <translation>オフ</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="142"/>
        <source>Alphanumeric</source>
        <translation>英数字</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="143"/>
        <source>Katakana</source>
        <translation>カタカナ</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="148"/>
        <source>Direct input</source>
        <translation>直接入力</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="150"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="151"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="152"/>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="154"/>
        <source>Yen Sign Â¥</source>
        <translation>円記号(¥)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="155"/>
        <source>Backslash \</source>
        <translation>バックスラッシュ(\)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="420"/>
        <source>Romaji/Kana setting is enabled from new applications.</source>
        <translation>ローマ字・かな入力の設定は新しいアプリケーションから有効になります。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="599"/>
        <source>Checking sync status</source>
        <translation>同期状態を確認する</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="601"/>
        <location filename="config_dialog.cc" line="1109"/>
        <source>Sync is not enabled</source>
        <translation>同期機能：オフ</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="749"/>
        <location filename="config_dialog.cc" line="771"/>
        <source>Mozc Converter is not running. Settings were not saved.</source>
        <translation>変換サーバが反応していません。設定の反映に失敗しました。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="873"/>
        <source>Web Service extension enables Mozc to display third party usage dictionaries provided as an Web service API, e.g. REST (POX/JSON over HTTP). Note that candidate/preedit strings are sent to the Web service when this feature is enabled. Do you want to use Web Service extension?</source>
        <translation>Web 拡張を有効にすると、Web サービス (REST, POX/JSON over HTTP) が提供するコンテンツを Mozcの用例辞書として表示可能となります。候補ウインドウに表示中の文字列が外部サーバに送信されることにご注意下さい。続けますか?</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="896"/>
        <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
 - Personalization data
 - Input history
 - Sync settings
 - Usage statistics and crash reports
 - Administrator settings</source>
        <translation>この機能を実行すると Mozcの設定が標準状態に戻ります。実行しますか？ 以下の設定はリセットされません。
 - 学習履歴
 - 入力履歴
 - 同期設定
 - 使用統計と障害レポート
 - 管理者用設定</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="948"/>
        <source>Stop Sync</source>
        <translation>同期の解除</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="950"/>
        <source>Start Sync</source>
        <translation>同期する</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="966"/>
        <source>Stop sync and reset the auth token</source>
        <translation>同期の解除と認証コードのクリア</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="967"/>
        <source>You are trying to stop sync and reset the auth token. To restart sync, you will need to get a new auth token.
Do you really want to continue?</source>
        <translation>同期の解除と認証コードのクリアを行います。同期を再開するには、新しい認証コードを取得する必要があります。
実行しますか？</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1051"/>
        <source>Not synced yet</source>
        <translation>同期されていません</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1055"/>
        <source>Last synced time: </source>
        <translation>最終同期時刻: </translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1097"/>
        <source>Waiting for server to be ready</source>
        <translation>サーバの状態を確認しています.. この処理は最大2分かかります</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1126"/>
        <source>Authorization failed.</source>
        <translation>認証に失敗しました。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1129"/>
        <source>Cannot save dictionaries because Sync Dictionary exceeds its entry size limit.</source>
        <translation>単語数の上限を超えたため同期用辞書をセーブできません。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1133"/>
        <source>Cannot save dictionaries because Sync Dictionary exceeds its binary size limit.</source>
        <translation>ファイルサイズの上限を超えたため同期用辞書をセーブできません。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1137"/>
        <source>Cannot save dictionaries because the number of dictionaries for sync exceeds its limit.</source>
        <translation>同期用辞書の数が上限を超えたため辞書をセーブできません。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1141"/>
        <source>Unknown error was found.</source>
        <translation>未知のエラーです。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1153"/>
        <source>Authorization error</source>
        <translation>認証失敗</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1158"/>
        <source>Dictionary sync error</source>
        <translation>辞書同期エラー</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1161"/>
        <source>Unknown sync error</source>
        <translation>未知の同期エラー</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1176"/>
        <source>You are trying to clear all the data in the sync server.
Do you really want to continue?</source>
        <translation>Google サーバー上の同期データを全て消去します。
実行しますか？</translation>
    </message>
    <message>
        <source>Sync succeeded. </source>
        <translation type="obsolete">同期成功</translation>
    </message>
    <message>
        <source>Sync failed</source>
        <translation type="obsolete">同期失敗</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1103"/>
        <source>During synchronization</source>
        <translation>同期中です</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="1175"/>
        <source>Clear all sync data in Google servers</source>
        <translation>Google サーバー上の同期データを全て消去する</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="385"/>
        <location filename="config_dialog.cc" line="405"/>
        <location filename="config_dialog.cc" line="419"/>
        <location filename="config_dialog.cc" line="427"/>
        <location filename="config_dialog.cc" line="734"/>
        <location filename="config_dialog.cc" line="748"/>
        <location filename="config_dialog.cc" line="758"/>
        <location filename="config_dialog.cc" line="770"/>
        <location filename="config_dialog.cc" line="780"/>
        <location filename="config_dialog.cc" line="792"/>
        <location filename="config_dialog.cc" line="872"/>
        <location filename="config_dialog.cc" line="895"/>
        <source>Mozc settings</source>
        <translation>Mozc プロパティ</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="278"/>
        <source>Dictionary preloading</source>
        <translation>オンメモリ辞書の設定</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="386"/>
        <source>Failed to get current config values</source>
        <translation>設定の取得に失敗しました。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="406"/>
        <source>The current custom keymap table is empty. When custom keymap is selected, you must customize it.</source>
        <translation>有効なキー設定がありません。カスタム キーマップを選択した場合は、キーマップを編集する必要があります。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="428"/>
        <source>Failed to update config</source>
        <translation>設定の反映に失敗しました</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="735"/>
        <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
        <translation>学習結果がリセットされます。実行しますか？ 入力履歴データはリセットされません。入力履歴データのリセットは「サジェスト→全入力履歴の削除」で行えます。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="793"/>
        <source>Mozc Converter is not running. Operation was not executed.</source>
        <translation>Mozcコンバーターが起動していません。設定の反映に失敗しました。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="759"/>
        <source>Do you want to clear all history data?</source>
        <translation>すべての入力履歴が削除されます。実行しますか？</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="781"/>
        <source>Do you want to clear unused history data?</source>
        <translation>サジェスト経由で入力されなかった履歴が削除されます。実行しますか？</translation>
    </message>
</context>
<context>
    <name>mozc::gui::GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.cc" line="60"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="132"/>
        <location filename="generic_table_editor.cc" line="177"/>
        <location filename="generic_table_editor.cc" line="188"/>
        <location filename="generic_table_editor.cc" line="210"/>
        <location filename="generic_table_editor.cc" line="218"/>
        <location filename="generic_table_editor.cc" line="226"/>
        <location filename="generic_table_editor.cc" line="248"/>
        <source>Mozc settings</source>
        <translation>Mozc プロパティ</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="133"/>
        <location filename="generic_table_editor.cc" line="178"/>
        <source>No entry is selected</source>
        <translation>エントリーが選択されていません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="189"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation>%1 個以上のエントリーは登録できません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="201"/>
        <source>import from file</source>
        <translation>インポート</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="211"/>
        <source>File not found</source>
        <translation>ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="219"/>
        <source>The specified file is too large (&gt;=100K byte)</source>
        <translation>ファイルサイズが大きすぎて読み込めません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="227"/>
        <source>Import failed</source>
        <translation>インポートに失敗しました</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="238"/>
        <source>export to file</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="249"/>
        <source>Export failed</source>
        <translation>エクスポートに失敗しました</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="282"/>
        <source>New entry</source>
        <translation>新しいエントリー</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="283"/>
        <source>Remove entry</source>
        <translation>エントリーを削除</translation>
    </message>
</context>
<context>
    <name>mozc::gui::KeyMapEditorDialog</name>
    <message>
        <location filename="keymap_editor.cc" line="220"/>
        <source>New entry</source>
        <translation>新しいエントリー</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="222"/>
        <source>Remove selected entries</source>
        <translation>選択されたエントリーを削除</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="226"/>
        <source>Import predefined mapping</source>
        <translation>定義済みのキーマップからインポート</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="230"/>
        <source>ATOK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="231"/>
        <source>MS-IME</source>
        <translation></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="232"/>
        <source>Kotoeri</source>
        <translation>ことえり</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="236"/>
        <source>Import from file...</source>
        <translation>インポート...</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="238"/>
        <source>Export to file...</source>
        <translation>エクスポート...</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="280"/>
        <source>Mozc keymap editor</source>
        <translation>Mozc キー設定</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="284"/>
        <source>Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="284"/>
        <source>Key</source>
        <translation>入力キー</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="284"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="368"/>
        <location filename="keymap_editor.cc" line="408"/>
        <location filename="keymap_editor.cc" line="427"/>
        <location filename="keymap_editor.cc" line="463"/>
        <source>Mozc settings</source>
        <translation>Mozcプロパティ</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="369"/>
        <source>Current keymap table is empty. You might want to import a pre-defined keymap table first</source>
        <translation>有効なキーマップがありません。定義済みのキーマップをインポートするか、有効なキーマップを追加してください。</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="409"/>
        <source>Invalid key:
%1</source>
        <translation>無効な入力キーです:
%1</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="428"/>
        <source>The keymaps for IME ON and Reconversion will be applied after new applications.</source>
        <translation>IME の有効化と再変換に対するキー設定は、新しいアプリケーションから有効になります。</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="464"/>
        <source>Do you want to overwrite the current keymaps?</source>
        <translation>現在のキー設定が上書きされます。実行しますか？</translation>
    </message>
</context>
<context>
    <name>mozc::gui::RomanTableEditorDialog</name>
    <message>
        <location filename="roman_table_editor.cc" line="32"/>
        <source>New entry</source>
        <translation>新しいエントリー</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="34"/>
        <source>Remove selected entries</source>
        <translation>選択されたエントリーを削除</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="37"/>
        <source>Import from file...</source>
        <translation>インポート...</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="39"/>
        <source>Export to file...</source>
        <translation>エクスポート...</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="42"/>
        <source>Reset to defaults</source>
        <translation>初期値に戻す</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="44"/>
        <source>Mozc Romaji table editor</source>
        <translation>Mozcローマ字テーブル設定</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Input</source>
        <translation>入力</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Output</source>
        <translation>出力</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Next input</source>
        <translation>次の入力</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="127"/>
        <location filename="roman_table_editor.cc" line="148"/>
        <location filename="roman_table_editor.cc" line="188"/>
        <location filename="roman_table_editor.cc" line="215"/>
        <source>Mozc settings</source>
        <translation>Mozcプロパティ</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="128"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation>%1 個以上のエントリーは登録できません</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="149"/>
        <source>Romaji to Kana table is empty.</source>
        <translation>ローマ字テーブルが空です</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="189"/>
        <source>Input fields contain capital characters. &quot;Shift-mode-switch&quot; function is disabled with this new mapping.</source>
        <translation>入力フィールドに大文字のアルファベットが含まれています。新しい設定では「シフトキーによる入力切替」は無効になります。</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="216"/>
        <source>Do you want to overwrite the current roman table?</source>
        <translation>現在のローマ字テーブルを上書きしますか？</translation>
    </message>
</context>
<context>
    <name>mozc::gui::WebServiceInfolistEditorDialog</name>
    <message>
        <location filename="webservice_infolist_editor.cc" line="99"/>
        <source>New entry</source>
        <translation>新しいエントリー</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="101"/>
        <source>Remove selected entries</source>
        <translation>選択されたエントリーを削除</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="104"/>
        <source>Import from file...</source>
        <translation>インポート...</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="106"/>
        <source>Export to file...</source>
        <translation>エクスポート...</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="109"/>
        <source>Help...</source>
        <translation>ヘルプ...</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="111"/>
        <source>Mozc Web Service Usage Dictionary table editor</source>
        <translation>Mozc Web 拡張用例辞書設定</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="123"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="123"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="124"/>
        <source>Format type</source>
        <translation>フォーマット</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="124"/>
        <source>Xpath/Jsonpath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="192"/>
        <source>Enter name of Web service</source>
        <translation>Web サービスの名称を入力します</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="193"/>
        <source>Enter URL for of Web service.
&quot;%s&quot; is expanded to the candidate string.
&quot;%r&quot; is expanded to the all preedit string.

Example:   http://api.sample.com/keyword/%s</source>
        <translation>外部 Web サービスのURLを入力します
以下のマクロが使用できます
&quot;%s&quot; : 候補ウインドウに表示されている文字列
&quot;%r&quot; : 変換文字列全体

例:   http://api.sample.com/keyword/%s</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="197"/>
        <source>Select format type</source>
        <translation>フォーマットを選択します</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="198"/>
        <source>Enter Xpath or Jsonpath.
This query is used for extracting the content from URL.

Example of Xpath:   //content/node
Example of Jsonpath:   $.content.node</source>
        <translation>XPath または Jsonpath クエリを入力します
対象の URL からこのクエリにマッチする文字列を用例辞書として表示します

Xpath の例:   //content/node
Jsonpath の例:   $.content.node</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="235"/>
        <source>Mozc settings</source>
        <translation>Mozc プロパティ</translation>
    </message>
    <message>
        <location filename="webservice_infolist_editor.cc" line="236"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation>%1 個以上のエントリーは登録できません</translation>
    </message>
    <message>
        <source>Do you want to overwrite the current roman table?</source>
        <translation type="obsolete">現在のローマ字テーブルを上書きしますか？</translation>
    </message>
</context>
</TS>
